@@ -13,13 +13,14 @@ from plinth.modules.firewall.components import Firewall
 from plinth.modules.letsencrypt.components import LetsEncrypt
 from plinth.utils import format_lazy
 
-version = 7
+version = 8
 
 is_essential = True
 
-managed_services = ['apache2']
+managed_services = ['apache2', 'uwsgi']
 
-managed_packages = ['apache2', 'php-fpm', 'ssl-cert']
+managed_packages = ['apache2', 'php-fpm', 'ssl-cert', 'uwsgi',
+                    'uwsgi-plugin-python3']
 
 app = None
 
@@ -56,13 +57,6 @@ class ApacheApp(app_module.App):
         self.add(daemon)
 
 
-def init():
-    """Initailze firewall module"""
-    global app
-    app = ApacheApp()
-    app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Configure the module."""
     helper.install(managed_packages)
