@@ -20,6 +20,8 @@ from . import api
 
 version = 2
 
+is_essential = True
+
 managed_packages = ['borgbackup', 'sshfs']
 
 depends = ['storage']
@@ -43,10 +45,11 @@ class BackupsApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               depends=depends, name=_('Backups'),
-                               icon='fa-files-o', description=_description,
-                               manual_page='Backups')
+        info = app_module.Info(
+            app_id=self.app_id, version=version, depends=depends,
+            name=_('Backups'), icon='fa-files-o', description=_description,
+            manual_page='Backups',
+            donation_url='https://www.borgbackup.org/support/fund.html')
         self.add(info)
 
         menu_item = menu.Menu('menu-backups', info.name, None, info.icon,
@@ -54,16 +57,6 @@ class BackupsApp(app_module.App):
         self.add(menu_item)
 
 
-def init():
-    """Initialize the module."""
-    global app
-    app = BackupsApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
