@@ -46,11 +46,12 @@ class DelugeApp(app_module.App):
             'bit-torrent': _('Download files using BitTorrent applications')
         }
 
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               name=_('Deluge'), icon_filename='deluge',
-                               short_description=_('BitTorrent Web Client'),
-                               description=_description, manual_page='Deluge',
-                               clients=clients)
+        info = app_module.Info(
+            app_id=self.app_id, version=version, name=_('Deluge'),
+            icon_filename='deluge',
+            short_description=_('BitTorrent Web Client'),
+            description=_description, manual_page='Deluge', clients=clients,
+            donation_url='https://www.patreon.com/deluge_cas')
         self.add(info)
 
         menu_item = menu.Menu('menu-deluge', info.name, info.short_description,
@@ -88,16 +89,6 @@ class DelugeApp(app_module.App):
         self.add(users_and_groups)
 
 
-def init():
-    """Initialize the Deluge module."""
-    global app
-    app = DelugeApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
