@@ -35,12 +35,6 @@ _description = [
       'configuration process.')
 ]
 
-port_forwarding_info = [
-    ('TCP', 4444),
-    ('TCP', 4445),
-    ('TCP', 6668),
-]
-
 tunnels_to_manage = {
     'I2P HTTP Proxy': 'i2p-http-proxy-freedombox',
     'I2P HTTPS Proxy': 'i2p-https-proxy-freedombox',
@@ -61,11 +55,11 @@ class I2PApp(app_module.App):
 
         groups = {'i2p': _('Manage I2P application')}
 
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               name=_('I2P'), icon_filename='i2p',
-                               short_description=_('Anonymity Network'),
-                               description=_description, manual_page='I2P',
-                               clients=clients)
+        info = app_module.Info(
+            app_id=self.app_id, version=version, name=_('I2P'),
+            icon_filename='i2p', short_description=_('Anonymity Network'),
+            description=_description, manual_page='I2P', clients=clients,
+            donation_url='https://geti2p.net/en/get-involved/donate')
         self.add(info)
 
         menu_item = menu.Menu('menu-i2p', info.name, info.short_description,
@@ -103,16 +97,6 @@ class I2PApp(app_module.App):
         self.add(users_and_groups)
 
 
-def init():
-    """Initialize the module."""
-    global app
-    app = I2PApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
