@@ -52,7 +52,8 @@ class IkiwikiApp(app_module.App):
                                name=_('ikiwiki'), icon_filename='ikiwiki',
                                short_description=_('Wiki and Blog'),
                                description=_description, manual_page='Ikiwiki',
-                               clients=clients)
+                               clients=clients,
+                               donation_url='https://ikiwiki.info/tipjar/')
         self.add(info)
 
         menu_item = menu.Menu('menu-ikiwiki', info.name,
@@ -101,16 +102,6 @@ class IkiwikiApp(app_module.App):
         return sites
 
 
-def init():
-    """Initialize the ikiwiki module."""
-    global app
-    app = IkiwikiApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
