@@ -18,11 +18,10 @@ from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.letsencrypt.components import LetsEncrypt
-from plinth.utils import Version
 
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 5
+version = 6
 
 managed_services = ['matrix-synapse']
 
@@ -40,16 +39,18 @@ _description = [
       'servers via federation.'),
     _('To communicate, you can use the '
       '<a href="https://matrix.org/docs/projects/">available clients</a> '
-      'for mobile, desktop and the web. <a href="https://riot.im/">Riot</a> '
-      'client is recommended.')
+      'for mobile, desktop and the web. '
+      '<a href="https://element.io/">Element</a> client is recommended.')
 ]
 
-port_forwarding_info = [('TCP', 8448)]
-
 logger = logging.getLogger(__name__)
 
 SERVER_NAME_PATH = "/etc/matrix-synapse/conf.d/server_name.yaml"
-CONFIG_FILE_PATH = '/etc/matrix-synapse/homeserver.yaml'
+ORIG_CONF_PATH = '/etc/matrix-synapse/homeserver.yaml'
+STATIC_CONF_PATH = '/etc/matrix-synapse/conf.d/freedombox-static.yaml'
+LISTENERS_CONF_PATH = '/etc/matrix-synapse/conf.d/freedombox-listeners.yaml'
+REGISTRATION_CONF_PATH = \
+    '/etc/matrix-synapse/conf.d/freedombox-registration.yaml'
 
 app = None
 
@@ -106,44 +107,32 @@ class MatrixSynapseApp(app_module.App):
         self.add(daemon)
 
 
-def init():
-    """Initialize the matrix-synapse module."""
-    global app
-    app = MatrixSynapseApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
-    helper.call('post', actions.superuser_run, 'matrixsynapse',
-                ['post-install'])
-    helper.call('post', app.enable)
+    if old_version and old_version < 6:
+        helper.call('post', upgrade, helper)
+    else:
+        helper.call('post', actions.superuser_run, 'matrixsynapse',
+                    ['post-install'])
+
+    if not old_version:
+        helper.call('post', app.enable)
+
     app.get_component('letsencrypt-matrixsynapse').setup_certificates()
 
 
-def force_upgrade(helper, packages):
-    """Force upgrade matrix-synapse to resolve conffile prompt."""
-    if 'matrix-synapse' not in packages:
-        return False
-
-    # Allow any lower version to upgrade to 1.15.*
-    package = packages['matrix-synapse']
-    if Version(package['new_version']) > Version('1.16~'):
-        return False
-
+def upgrade(helper):
+    """Upgrade matrix-synapse configuration to avoid conffile prompt."""
     public_registration_status = get_public_registration_status()
-    helper.install(['matrix-synapse'], force_configuration='new')
+    actions.superuser_run('matrixsynapse', ['move-old-conf'])
+    helper.install(['matrix-synapse'], force_configuration='new',
+                   reinstall=True, force_missing_configuration=True)
     actions.superuser_run('matrixsynapse', ['post-install'])
     if public_registration_status:
         actions.superuser_run('matrixsynapse',
                               ['public-registration', 'enable'])
 
-    return True
-
 
 def setup_domain(domain_name):
     """Configure a domain name for matrixsynapse."""
