@@ -89,16 +89,6 @@ class MLDonkeyApp(app_module.App):
         self.add(users_and_groups)
 
 
-def init():
-    """Initialize the MLDonkey module."""
-    global app
-    app = MLDonkeyApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.call('pre', actions.superuser_run, 'mldonkey', ['pre-install'])
