@@ -2,6 +2,7 @@
 
 from django import forms
 from django.core import validators
+from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import cfg, network
@@ -34,8 +35,7 @@ class ConnectionForm(forms.Form):
         label=_('Firewall Zone'),
         help_text=_('The firewall zone will control which services are '
                     'available over this interfaces. Select Internal only '
-                    'for trusted networks.'),
-        choices=[('external', _('External')), ('internal', _('Internal'))])
+                    'for trusted networks.'), choices=network.ZONES)
     ipv4_method = forms.ChoiceField(
         label=_('IPv4 Addressing Method'), help_text=format_lazy(
             _('"Automatic" method will make {box_name} acquire '
@@ -44,7 +44,8 @@ class ConnectionForm(forms.Form):
               'clients on this network and share its Internet connection.'),
             box_name=_(cfg.box_name)),
         choices=[('auto', _('Automatic (DHCP)')), ('shared', _('Shared')),
-                 ('manual', _('Manual')), ('disabled', _('Disabled'))])
+                 ('manual', pgettext_lazy('Not automatically', 'Manual')),
+                 ('disabled', _('Disabled'))])
     ipv4_address = forms.CharField(
         label=_('Address'), validators=[validators.validate_ipv4_address],
         required=False)
@@ -74,7 +75,8 @@ class ConnectionForm(forms.Form):
               'configuration from this network making it a client.'),
             box_name=_(cfg.box_name)),
         choices=[('auto', _('Automatic')), ('dhcp', _('Automatic, DHCP only')),
-                 ('manual', _('Manual')), ('ignore', _('Ignore'))])
+                 ('manual', pgettext_lazy('Not automatically', 'Manual')),
+                 ('ignore', _('Ignore'))])
     ipv6_address = forms.CharField(
         label=_('Address'), validators=[validators.validate_ipv6_address],
         required=False)
