@@ -60,12 +60,12 @@ class PagekiteApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               depends=depends, name=_('PageKite'),
-                               icon='fa-flag',
-                               short_description=_('Public Visibility'),
-                               description=_description,
-                               manual_page='PageKite')
+        info = app_module.Info(
+            app_id=self.app_id, version=version, depends=depends,
+            name=_('PageKite'), icon='fa-flag',
+            short_description=_('Public Visibility'), description=_description,
+            manual_page='PageKite',
+            donation_url='https://pagekite.net/support/faq/#donate')
         self.add(info)
 
         menu_item = menu.Menu('menu-pagekite', info.name,
@@ -80,6 +80,11 @@ class PagekiteApp(app_module.App):
         daemon = Daemon('daemon-pagekite', managed_services[0])
         self.add(daemon)
 
+        # Register kite name with Name Services module.
+        setup_helper = globals()['setup_helper']
+        if setup_helper.get_state() != 'needs-setup' and self.is_enabled():
+            utils.update_names_module(is_enabled=True)
+
     def enable(self):
         """Send domain signals after enabling the app."""
         super().enable()
@@ -91,19 +96,6 @@ class PagekiteApp(app_module.App):
         super().disable()
 
 
-def init():
-    """Initialize the PageKite module"""
-    global app
-    app = PagekiteApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-        # Register kite name with Name Services module.
-        utils.update_names_module(is_enabled=True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
