@@ -15,11 +15,11 @@ from plinth.modules.firewall.components import Firewall
 from plinth.modules.users.components import UsersAndGroups
 
 from .manifest import (PUBLIC_ACCESS_SETTING_FILE,  # noqa, pylint: disable=unused-import
-                       backup, clients)
+    backup, clients)
 
 version = 4
 
-managed_packages = ['searx', 'uwsgi', 'uwsgi-plugin-python3']
+managed_packages = ['searx']
 
 _description = [
     _('Searx is a privacy-respecting Internet metasearch engine. '
@@ -44,11 +44,11 @@ class SearxApp(app_module.App):
 
         groups = {'web-search': _('Search the web')}
 
-        info = app_module.Info(app_id=self.app_id, version=version,
-                               name=_('Searx'), icon_filename='searx',
-                               short_description=_('Web Search'),
-                               description=_description, manual_page='Searx',
-                               clients=clients)
+        info = app_module.Info(
+            app_id=self.app_id, version=version, name=_('Searx'),
+            icon_filename='searx', short_description=_('Web Search'),
+            description=_description, manual_page='Searx', clients=clients,
+            donation_url='https://searx.me/static/donate.html')
         self.add(info)
 
         menu_item = menu.Menu('menu-searx', info.name, info.short_description,
@@ -103,16 +103,6 @@ class SearxWebserverAuth(Webserver):
             super().enable()
 
 
-def init():
-    """Initialize the module."""
-    global app
-    app = SearxApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
