@@ -77,16 +77,6 @@ class ShadowsocksApp(app_module.App):
         self.add(daemon)
 
 
-def init():
-    """Initialize the module."""
-    global app
-    app = ShadowsocksApp()
-
-    setup_helper = globals()['setup_helper']
-    if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
-        app.set_enabled(True)
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
