@@ -36,7 +36,7 @@ class SharingApp(app_module.App):
         super().__init__()
         info = app_module.Info(app_id=self.app_id, version=version,
                                name=_('Sharing'), icon_filename='sharing',
-                               description=_description)
+                               manual_page='Sharing', description=_description)
         self.add(info)
 
         menu_item = menu.Menu('menu-sharing', info.name, None,
@@ -45,13 +45,6 @@ class SharingApp(app_module.App):
         self.add(menu_item)
 
 
-def init():
-    """Initialize the module."""
-    global app
-    app = SharingApp()
-    app.set_enabled(True)
-
-
 def list_shares():
     """Return a list of shares."""
     output = actions.superuser_run('sharing', ['list'])
