@@ -5,7 +5,7 @@ IFS=$'\n\t'
 echo "Installing requirements"
 sudo apt-get install -yq --no-install-recommends \
     python3-pytest python3-pytest-django \
-    python3-pip firefox smbclient\
+    python3-pip firefox-esr smbclient\
     xvfb
 pip3 install wheel
 pip3 install splinter pytest-splinter pytest-bdd pytest-xvfb pytest-xdist
