@@ -67,6 +67,7 @@ def is_user_admin(request, cached=False):
 
 class YAMLFile(object):
     """A context management class for updating YAML files"""
+
     def __init__(self, yaml_file):
         """Return a context object for the YAML file.
 
@@ -156,3 +157,10 @@ def is_axes_old():
         return False
 
     return LooseVersion(version) < LooseVersion('5.0')
+
+
+def is_authenticated_user(username, password):
+    """Return true if the user authentication succeeds."""
+    import pam  # Minimize dependencies for running tests
+    pam_authenticator = pam.pam()
+    return bool(pam_authenticator.authenticate(username, password))
